@@ -1,18 +1,18 @@
-;;; -*- Emacs-Lisp -*-
-;;; <plaintext>
-;;; revive.el: Resume Emacs.
-;;; (c) 1994-2003 by HIROSE Yuuji [yuuji@gentei.org]
-;;; $Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp yuuji $
-;;; Last modified Fri May  6 11:54:46 2005 on firestorm
+;;; revive.el --- Resume Emacs -*- coding: euc-jp -*-
+;;; (c) 1994-2012 by HIROSE Yuuji [yuuji@gentei.org]
+;;; $Id: revive.el,v 2.21 2012/08/12 11:56:06 yuuji Exp yuuji $
+;;; Last modified Thu Oct 18 14:47:17 2012 on firestorm
 
 ;;;[[[   NOTICE  NOTICE  NOTICE  NOTICE  NOTICE    ]]]
 ;;;--------------------------------------------------------------------------
 ;;;	If you are using `windows.el', you can omit the settings of
 ;;;	define-key and autoload.
-;;;	windows.el𕁒igĂꍇ revive.el ̂߂̃L[̊蓖
-;;;	Ăautoload̐ݒKv܂B
+;;;	windows.elʻȤäƤ revive.el ΤΥγ
+;;;	Ƥautoload⤹ɬפޤ
 ;;;--------------------------------------------------------------------------
 ;;;
+;;; Commentary:
+;;;
 ;;;		Resume Emacs:		revive.el
 ;;;
 ;;;[What is `revive'?]
@@ -135,98 +135,100 @@
 ;;;
 ;;; Japanese Document follows:
 ;;;
-;;;yreviveƂ́z
+;;;reviveȤϡ
 ;;;
-;;;	  revive.el gƁAEmacs gp̏Ԃt@CɃZ[uāA
-;;;	 Emacs N鎞ɂ̏ԂɕA邱Ƃł܂B
-;;;	EBhE̕Ԃ̂ saveconf  desktop 
-;;;	炢炵Ălɂ߂łB
+;;;	  revive.el ȤȡEmacs ѻξ֤ե˥֤ơ
+;;;	 Emacs ưˤξ֤뤳ȤǤޤ
+;;;	󥦥ɥʬ֤Τ saveconf  desktop 
+;;;	餤餷Ƥͤˤ⤪Ǥ
 ;;;
-;;;ygݍݕz
+;;;Ȥ߹
 ;;;
-;;;	  revive.el  load-path ̒ʂfBNgɓA~/.emacs 
-;;;	ȉ̋LqĂB
+;;;	  revive.el  load-path ̤äǥ쥯ȥ졢~/.emacs 
+;;;	ʲεҤƤ
 ;;;
 ;;;	  (autoload 'save-current-configuration "revive" "Save status" t)
 ;;;	  (autoload 'resume "revive" "Resume Emacs" t)
 ;;;	  (autoload 'wipe "revive" "Wipe emacs" t)
 ;;;
-;;;	ď̊֐DȃL[Ɋ蓖ĂĂBȉ͗łB
+;;;	ƾδؿ򹥤ʥ˳ƤƤʲǤ
 ;;;
 ;;;	  (define-key ctl-x-map "S" 'save-current-configuration)
 ;;;	  (define-key ctl-x-map "F" 'resume)
 ;;;	  (define-key ctl-x-map "K" 'wipe)
 ;;;
-;;;ygz
+;;;ڻȤ
 ;;;
-;;;	   define-key ꍇɂ́AC-x S Ō݂̕ҏWԂZ[u
-;;;	邱Ƃł܂Bsave-current-configuration ֐ɐ
-;;;	ƕ̏ԂʁXɃZ[uł܂BuC-u 2 C-x SvƂ2
-;;;	Ԃ̃obt@ɌZ[uł܂B[h鎞l
-;;;	uC-u 2 C-x Fvƃ^Cv2Ԃ̃obt@Ԃ[h܂B
+;;;	   define-key 򤷤ˤϡC-x S ǸߤԽ֤򥻡
+;;;	뤳ȤǤޤsave-current-configuration ؿ˿
+;;;	ʣξ̡֤˥֤ǤޤC-u 2 C-x SפȤ2
+;;;	֤ΥХåե˸򥻡֤ǤޤɤƱͤ
+;;;	C-u 2 C-x Fפȥפ2֤ΥХåե֤ɤޤ
 ;;;
-;;;yϐ̃Z[uz
+;;;ѿΥ֡
 ;;;
-;;;	  ϐ̒lZ[uĂƂł܂BftHgŃZ[u 
-;;;	global ϐ revive:save-variables-global-default ɁAlocal 
-;;;	 revive:save-variables-local-default ɒ`Ă܂B
-;;;	̕ϐۑꍇ́Arevive:save-variables-global-private 
-;;;	 global ϐArevive:save-variables-local-private  local 
-;;;	ϐꂼꃊXǧ`Œ`Ă܂BႦ gmhist g
-;;;	Ăꍇɂ́A
+;;;	  ѿͤ⥻֤ƤȤǤޤǥեȤǥ֤
+;;;	global ѿ revive:save-variables-global-default ˡlocal 
+;;;	 revive:save-variables-local-default Ƥޤ
+;;;	ѿ¸ϡrevive:save-variables-global-private
+;;;	 global ѿ̾revive:save-variables-local-private  local
+;;;	ѿ̾򤽤줾ꥹȤηƤޤ㤨 gmhist Ȥ
+;;;	Ƥˤϡ
 ;;;
 ;;;		(setq revive:save-variables-global-private
 ;;;		      '(file-history buffer-history minibuffer-history))
 ;;;
-;;;	Ȃǂ ~/.emacs ɏĂƉKł傤B
+;;;	ʤɤ ~/.emacs ˽񤤤ƤȲŬǤ礦
 ;;;
-;;;yʂłȂobt@̈z
+;;;̤ǤʤХåեΰ
 ;;;
-;;;	  mh-rmail ł̓Jgobt@ mh-folder-mode, gnus ł̓J
-;;;	gobt@ gnus-Group-mode ɂȂ܂B̑Ή֌ẂAϐ 
-;;;	revive:major-mode-command-alist-default ɏĂ܂B̕
-;;;	ɓo^ĂȊÔ̂`ꍇ́A
+;;;	  mh-rmail ǤϥȥХåե mh-folder-mode, gnus Ǥϥ
+;;;	ȥХåե gnus-Group-mode ˤʤޤбطϡѿ
+;;;	revive:major-mode-command-alist-default ˽񤫤Ƥޤ
+;;;	ϿƤʳΤΤϡ
 ;;;
 ;;;		(setq revive:major-mode-command-alist-private
 ;;;		  '((hogehoge-mode	. hoge)
 ;;;		    (herohero-mode	. herohero)
-;;;		    ("^Cvj["	. trr)))
+;;;		    ("ס˥塼"	. trr)))
 ;;;
-;;;	̂悤 revive:major-mode-command-alist-private ̒lݒ肷
-;;;	Ǝ resume ɎIɑΉR}hN܂B
-;;;	̗ɂ悤ɁAmajor-mode(V{)̑ buffer-name
-;;;	()w肷邱Ƃł܂B
+;;;	Τ褦 revive:major-mode-command-alist-private ͤꤹ
+;;;	ȼ resume ˼ưŪб륳ޥɤưޤ
+;;;	ˤ褦ˡmajor-mode(ܥ) buffer-name
+;;;	(ʸ)ꤹ뤳ȤǤޤ
 ;;;
-;;;	  ܂ASKK̎̂悤ɃW[Ƃ܂ȂȂĂ
-;;;	܂obt@ꍇ́Aϐ revive:ignore-buffer-pattern ɂ
-;;;	̃obt@}b`悤ȐK\ݒ肵ĂB
+;;;	  ޤSKKμΤ褦˥ꥸ塼हȤޤưʤʤäƤ
+;;;	ޤХåեϡѿ revive:ignore-buffer-pattern ˤ
+;;;	ΥХåե̾ޥå褦ɽꤷƤ
 ;;;
-;;;yvOgz
+;;;ڥץफȤ
 ;;;
-;;;	  pŃhLg [For programmers] ̍QƂĂB
+;;;	  Ѹǥɥ [For programmers] ι򻲾ȤƤ
 ;;;
-;;;yƂz
+;;;ڤȤ
 ;;;
-;;;	  ŏ resume Ƃt@ĈłAEmacs 19 ̃fB
-;;;	Ng resume.el Ƃt@CăVbN󂯂܂B
-;;;	̓R}hCŉ emacs ƑłĂAɋNĂ 
-;;;	emacs Ƀt@CnƂ(s[[)vOŁuǂ 
-;;;	resume ˂vƌȂ܂䖝 revive.el Ƀl[
-;;;	܂B܂Asaveconf ł desktop łȂȂ
-;;;	EBhEԂ̕T|[gƌ̂ɁcAȂĂ
-;;;	͉płɂ͏Ȃ:-)B
+;;;	  ǽ resume Ȥե̾äΤǤEmacs 19 Υǥ
+;;;	쥯ȥ resume.el Ȥե뤬äƥåޤ
+;;;	ϥޥɥ饤ǲ emacs ǤäƤ⡢˵ưƤ
+;;;	emacs ˥եϤȤ(ԡ)ץǡ֤ɤ
+;;;	resume ͤפȸʤޤ revive.el ˥͡
+;;;	षޤޤäsaveconf Ǥ desktop Ǥʤʤ
+;;;	ɥʬ֤򥵥ݡȤȸΤˡġʤƤ
+;;;	ϱѸǤˤϽ񤱤ʤ:-)
 ;;;
-;;;y舵z
+;;;ڼ갷
 ;;;
-;;;	  ̃vÓAt[\tgEFAƂ܂B̃vO
-;;;	gpĐȂ錋ʂɑ΂Ă҂͈؂̐ӔC𕉂
-;;;	̂Ƃ܂ARgoO|[g͑傢Ɋ}
-;;;	BCyɂABA͈ȉ̃AhX܂ł肢
-;;;	(2003/6)B
+;;;	  Υץϡե꡼եȥȤޤΥץ
+;;;	Ѥʤ̤ФƤԤϰڤǤ
+;;;	ΤȤޤȤХݡȤ礤˴ޤ
+;;;	ڤˤϢϢϰʲΥɥ쥹ޤǤꤤ
+;;;	(2012/8)
 ;;;							yuuji@gentei.org
 
+;;; Code:
+
 (defconst revive:version
-  "$Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp yuuji $"
+  "$Id: revive.el,v 2.21 2012/08/12 11:56:06 yuuji Exp yuuji $"
   "Version of revive.el")
 
 (defconst revive:version-prefix ";;;")
@@ -277,7 +279,7 @@
 		 (throw 'found nil)))))
 	(error "Unexpected window configuration."))
     (setq curwin win wlist (list win))
-    (while (not (eq curwin (setq win (next-window win))))
+    (while (not (eq curwin (setq win (next-window win "w/o mini"))))
       (setq wlist (append wlist (list win)))) ;use append to preserve order
     wlist))
 
@@ -382,7 +384,7 @@ EDGES is a list of sub-windows' edges."
      ;; |top   |2 |  horizontally.  And call this function recursively on
      ;; +---+--+--+  former (that is, upper half in vertical division or
      ;; |3  |4..  |  left half in horizontal) and latter configuration.
-     ;; +---+-----+  
+     ;; +---+-----+
      (t
       (let ((flist (list topwin))
 	    (elist (cdr edges)) divwin div-x div-y former latter)
@@ -426,12 +428,13 @@ EDGES is a list of sub-windows' edges."
     ;;(c-mode		. revive:c-set-style)
     ;;(cc-mode		. revive:c-set-style)
     ;;(java-mode		. revive:c-set-style)
+    (twittering-mode . revive:twittering)
     )
-  "Default alist of major-mode vs. command name.")
+  "Default alist of `major-mode' vs. command name.")
 (defvar revive:major-mode-command-alist-private nil
   "*User defined revive:major-mode-command-alist")
 (defvar revive:major-mode-command-alist nil
-  "*Alist of major-mode vs. commandname.")
+  "*Alist of `major-mode' vs. commandname.")
 (setq revive:major-mode-command-alist
       (append revive:major-mode-command-alist-private
 	      revive:major-mode-command-alist-default))
@@ -439,7 +442,7 @@ EDGES is a list of sub-windows' edges."
 (defvar revive:save-variables-global-default
   '(truncate-partial-width-windows
     make-backup-files version-control
-    visible-bell)
+    visible-bell file-name-history buffer-name-history minibuffer-history)
   "Default list of global variables to save.")
 (defvar revive:save-variables-global-private nil
   "*User defined list of the global variables to save.")
@@ -462,7 +465,8 @@ EDGES is a list of sub-windows' edges."
     (yahtml-mode YaTeX-parent-file)
     (c-mode c-indentation-style c-basic-offset)
     (cc-mode c-indentation-style c-basic-offset)
-    (java-mode c-indentation-style c-basic-offset))
+    (java-mode c-indentation-style c-basic-offset)
+    (twittering-mode twittering-timeline-spec-string))
   "Default list of the mode specific local variables to save.
 Actually, revive doesn't make the buffer local variables assuming
 those variable have already localized by their major mode.")
@@ -515,8 +519,7 @@ window-edges whose first member is always of north west window.
 Buffer-List is a list of buffer property list of all windows.  This
 property lists are stored in order corresponding to Edge-List.  Buffer
 property list is formed as
-'((buffer-file-name) (buffer-name) (point) (window-start)).
-"
+'((buffer-file-name) (buffer-name) (point) (window-start))."
   (let ((curwin (selected-window))
 	(wlist (revive:window-list)) (edges (revive:all-window-edges)) buflist)
     (save-excursion
@@ -613,7 +616,7 @@ current-window-configuration-printable."
 
 (defun revive:varlist (var2save)
   "Return the (variable . value) list of variables in VAR2SAVE."
-  (delq nil (mapcar 
+  (delq nil (mapcar
 	     (function (lambda (s)
 			 (if (and s (boundp s)) (cons s (symbol-value s)))))
 	     var2save)))
@@ -643,7 +646,7 @@ Variable-List is a return value of revive:varlist."
 	(local-var (append revive:save-variables-local-default
 			   revive:save-variables-local-private))
 	(mode-local-var (append revive:save-variables-mode-local-default
-				revive:save-variables-mode-local-private))) 
+				revive:save-variables-mode-local-private)))
     (save-excursion
       (run-hooks 'revive:buffer-property-list-hook)
       (while buflist
@@ -754,6 +757,7 @@ Variable-List is a return value of revive:varlist."
 	    (rename-buffer (revive:prop-buffer-name x)))
 	(set-mark (revive:prop-mark x))
 	(goto-char (revive:prop-point x))
+	(and (fboundp 'region-active-p) (region-active-p) (deactivate-mark))
 	(revive:restore-value (revive:prop-varlist x))))
       (setq blist (cdr blist)))
     (run-hooks 'revive:restore-buffers-hook)))
@@ -847,7 +851,7 @@ Configuration should be saved by save-current-configuration."
 	    "~/"))
   (or (and (boundp 'mew-path) mew-path)
       (and (fboundp 'mew-init) (let (mew-demo) (mew-init))))
-  (mew-cache-flush)			;Mew should take more care of 
+  (mew-cache-flush)			;Mew should take more care of
   (get-buffer-create " *mew tmp*")	;unexisting buffer...
   (let ((b (revive:prop-buffer-name x)))
     (cond
@@ -884,15 +888,31 @@ Configuration should be saved by save-current-configuration."
   (require 'cc-mode)
   (revive:find-file (revive:prop-file-name x))
   (funcall (revive:prop-major-mode x))
-  (c-set-style (or (revive:prop-get-value x 'c-indentation-style) "gnu"))
-)
+  (c-set-style (or (revive:prop-get-value x 'c-indentation-style) "gnu")))
+
+(defun revive:twittering ()
+  "Restore buffer of twittering mode.
+This functionality is considered to be migrated from `twittering-mode'."
+  (interactive)
+  (require 'twittering-mode)
+  (twittering-visit-timeline
+   (revive:prop-get-value x 'twittering-timeline-spec-string)))
 
-;;(provide 'resume)
 (provide 'revive)
 
 
-;; $Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp yuuji $
+;; $Id: revive.el,v 2.21 2012/08/12 11:56:06 yuuji Exp yuuji $
 ;; $Log: revive.el,v $
+;; Revision 2.21  2012/08/12 11:56:06  yuuji
+;; Switched to euc-jp.
+;;
+;; Revision 2.20  2012/07/25 23:37:38  yuuji
+;; Update headers and headings.
+;;
+;; Revision 2.19  2008/05/13 01:19:16  yuuji
+;; Add below to revive:save-variables-global-default.
+;; * file-name-history buffer-name-history minibuffer-history
+;;
 ;; Revision 2.18  2003/06/22 05:11:46  yuuji
 ;; revive:c-set-style disabled.
 ;;
@@ -978,3 +998,4 @@ Configuration should be saved by save-current-configuration."
 ; paragraph-start: "^$\\|\\|;;;$"
 ; paragraph-separate: "^$\\|\\|;;;$"
 ; End:
+;;; revive.el ends here
