@@ -1,9 +1,10 @@
-;;; -*- Emacs-Lisp -*-
-;;; Window manager for GNU Emacs.
-;;; $Id: windows.el,v 2.41 2007/06/06 11:29:29 yuuji Exp $
-;;; (c) 1993-2007 by HIROSE Yuuji [yuuji@gentei.org]
-;;; Last modified Wed Jun  6 20:29:19 2007 on firestorm
+;;; windows.el --- Window manager for GNU Emacs. -*- coding: euc-jp -*-
+;;; $Id: windows.el,v 2.48 2010/05/23 12:33:40 yuuji Exp yuuji $
+;;; (c) 1993-2013 by HIROSE Yuuji [yuuji@gentei.org]
+;;; Last modified Sun Jan 27 23:47:02 2013 on firestorm
 
+;;; Commentary:
+;;;
 ;;;		Window manager for GNU Emacs
 ;;;
 ;;;[What is Windows?]
@@ -613,11 +614,15 @@
 ;;;
 ;;;	  Υץ뤭äŬڤʥȤ򲼤äASCII-
 ;;;	NETΤ㡼ڤ Emacs-19 ǥߥ˥ХåեʬΥƤ
-;;;	εư˴ؤǥХå˶ϲäfujixerox.co.jpע
-;;;	줵󡢥˥塼ˤ륦ɥڤؤƤƤä() 
-;;;	Ǥξ٤XEmacsطưʤɤĺ紴פ
-;;;	ƥɥ̾Ĥ뵡ǽʤɤΥѥåĺؤ
-;;;	ܤ˴פޤ
+;;;	εư˴ؤǥХå˶ϲäfujixerox.co.jpע۰줵
+;;;	󡢥˥塼ˤ륦ɥڤؤƤƤä() 
+;;;	ξ٤XEmacsطưʤɤ򲼤ä紴פ󡢳
+;;;	ɥ̾Ĥ뵡ǽʤɤΥѥå򲼤äؤ
+;;;	ܤMew(5ʹ) win:use-frame nilǻȤȤԶ˴ؤ
+;;;	򲼤äĤEmacs22ʹ -nw ΤȤƱХåե
+;;;	̥ɥ˽ФƤ current-window-configuration 
+;;;	ȤǤʤβʣ *shell* Хåե
+;;;	ǽȤѥå򲼤äؤκ浮ʸ˴פޤ
 ;;;
 ;;;ڼ갷
 ;;;
@@ -625,12 +630,10 @@
 ;;;	ץѤʤ̤ФƤԤϰڤǤ
 ;;;	ʤΤȤޤȤХݡȤ礤˴
 ;;;	ޤڤˤϢϢϰʲΥɥ쥹ޤǤꤤ
-;;;	ޤ(2007/6)
+;;;	ޤ(2013/1)
 ;;;							yuuji@gentei.org
 
-;;;
-;; Code
-;;;
+;;; Code:
 
 ;; ---------- Customizable variables
 (defvar win:max-configs 10
@@ -804,6 +807,11 @@ make-frame function."
 (and (fboundp 'eval-when-compile)
      (eval-when-compile (require 'revive)))
 
+;; for Emacs-24.3+ and NEmacs
+(defun win:last-key ()
+  "Return last-command-event or last-command-char."
+  (if (boundp 'last-command-char) last-command-char last-command-event))
+
 (if win:switch-map nil
   (setq win:switch-map (make-sparse-keymap)
 	win:switch-menu-map (make-keymap))
@@ -980,7 +988,14 @@ make-frame function."
 			    (if killbufmsg "buffer and " "")
 			    (+ n win:base-key) (aref win:names n))))
       (progn
-	(if win:use-frame (delete-frame (aref win:configs n)))
+	(cond
+	 (win:use-frame (delete-frame (aref win:configs n)))
+	  ;; no use-frame
+	 ((and (fboundp 'delete-frame) (null window-system)
+	       (string< "20" emacs-version))
+	  (save-window-excursion
+	    (win:set-window-configuration (aref win:configs n))
+	    (delete-frame (selected-frame)))))
 	(aset win:configs n nil)
 	(aset win:names-prefix n "")
 	(if (= n win:current-config)
@@ -1044,12 +1059,15 @@ Optional third arg NOSETWC non-nil means do not set-window-configuration TO.
 	(if win:buffer-depth-per-win (win:restore-buffer-list to))
       (aset win:configs to nil)		;failed
       (error "Window frame [%c] does not exist." (+ win:base-key to))))
-   (t
+   (t					;NOT use-frame
     (or preserve (win:store-config win:current-config))
     (or nosetwc (win:set-wc to))
     (if win:buffer-depth-per-win
 	(save-window-excursion (win:restore-buffer-list to)))
-    ))
+    (and win:frames-in-nw
+	 (null (aref win:configs to))
+	 (select-frame
+	  (make-frame (list (cons 'name (format "W:%d" to))))))))
   (win:update-mode-line to)
   (if (/= to win:current-config)
       (setq win:last-config win:current-config
@@ -1094,10 +1112,11 @@ Non-nil for ARG kills all visible buffer."
 If calling from program, optional second argument WINDOW can specify
 the window number."
   (interactive "p")
-  (let*((window (or window
-                    (if (< last-command-char 0)
-                        (- last-command-char ?\M-0)
-                      (- last-command-char win:base-key))))
+  (let*((lc (win:last-key))
+	(window (or window
+                    (if (and (> ?\M-0 0) (<= ?\M-0 lc))
+                        (- lc ?\M-0)
+                      (- lc win:base-key))))
 	(wc (aref win:configs window)))
     (cond
      ((and win:inhibit-switch-in-minibuffer
@@ -1257,10 +1276,10 @@ the window number."
       (select-frame (aref win:configs win:current-config))
       (restore-window-configuration conf2))
      (t
-      (aset win:configs n (current-window-configuration))
+      (aset win:configs n (win:current-window-configuration))
       (win:set-window-name win:current-config)
       (aset win:names n (aref win:names win:current-config))
-      (set-window-configuration tmp))))
+      (win:set-window-configuration tmp))))
 )
 
 (defun win:read-config-file ()
@@ -1328,8 +1347,7 @@ Using from program, non-interactively, don't forget to specify second arg."
 (defun win-toggle-window ()
   "Toggle current window and most recently used one."
   (interactive)
-  (if win:use-frame
-      (win:adjust-window))
+  (win:adjust-window)
   (if (or (= win:last-config win:current-config)
 	  (equal (aref win:configs win:last-config) nil))
       (message "No other window")
@@ -1393,7 +1411,7 @@ If Windows uses frame(Emacs 19), Select the NUM-th window frame."
     (win:store-config 0)  ;;save current configuration into array[0]
     (if win:use-frame
 	(win:select-frame num)
-      (set-window-configuration wc))))
+      (win:set-window-configuration wc))))
 
 (cond
  ((fboundp 'screen-height)
@@ -1407,10 +1425,27 @@ If Windows uses frame(Emacs 19), Select the NUM-th window frame."
 (defun win:store-config (index)
   "(Windows low level intenal)Save current configuration in INDEX-th of array."
   (aset win:configs index
-	(if win:use-frame (selected-frame) (current-window-configuration)))
+	(if win:use-frame (selected-frame) (win:current-window-configuration)))
   (win:set-window-name index)
   (aset win:sizes index (list (win:screen-height) (win:screen-width))))
 
+(defun win:current-window-configuration ()
+  (cons (current-window-configuration) (point-marker)))
+
+(defun win:set-window-configuration (wc)
+  (prog1
+      (set-window-configuration (car wc))
+    (if (marker-buffer (cdr wc))
+	(progn (goto-char (cdr wc))
+	       (set-marker (cdr wc) nil)))))
+
+(defun win:get-frame (index)
+  "(windows internal) Get INDEX-th wnidows frame object"
+  (let ((obj (aref win:configs index)))
+    (if win:frames-in-nw
+	(if obj (window-configuration-frame (car-safe obj)) (selected-frame))
+      obj)))
+
 (defun win:set-window-name (index)
   "(Windows low level intenal)Set current window name to INDEX-th of array."
   (require 'revive)
@@ -1536,7 +1571,7 @@ Do not call this function."
 ;; Functions for resume.
 ;;;
 (defconst win:revision
-  "$Revision: 2.41 $"
+  "$Revision: 2.48 $"
   "Revision string of windows.el")
 (defvar win:revision-prefix ";win;")
 
@@ -1629,7 +1664,7 @@ Configuration to be saved is a list of
 		(progn
 		  (select-frame (aref win:configs i))
 		  (or win:no-raise-at-save (raise-frame (aref win:configs i))))
-	      (set-window-configuration (aref win:configs i)))
+	      (win:set-window-configuration (aref win:configs i)))
 	    (message "Saving window [%d]..." i)
 	    (win:save-window i)
 	    ))
@@ -1641,7 +1676,7 @@ Configuration to be saved is a list of
     (message "Saved all configurations in [%s]" win:configuration-file)
     (if win:use-frame
 	(win:select-frame win:current-config)
-      (set-window-configuration (aref win:configs win:current-config)))))
+      (win:set-window-configuration (aref win:configs win:current-config)))))
 
 (defun win:load-window (arg)
   "Load the ARG-th window configuration from the configuration file."
@@ -1713,8 +1748,8 @@ Configuration to be saved is a list of
 		    (+ (win:numericify (cdr y)) win:resumed-frame-offset-y)))
 	(if win:xemacs-p		;XEmacs is unwilling to set minibuffer
 	    (setq params (delq (assq 'minibuffer params) params)))
-	(modify-frame-parameters frame params)
-	))
+	(modify-frame-parameters frame params))
+    (win:switch-window (car config) t t))
   (if (nth 3 config) (aset win:names-prefix (car config) (nth 3 config)))
   (restore-window-configuration (car (cdr config))))
 
@@ -1796,6 +1831,7 @@ Non-nil for optional argument PRESERVE keeps all current buffers."
 	(while (not (frame-visible-p goal)) (sit-for 0))
 	(raise-frame goal)
 	(select-frame goal)
+	(if (fboundp 'x-focus-frame) (x-focus-frame goal))
 	(if (not (eq (selected-frame) goal))
 	    nil
 	  (or win:xemacs-p (unfocus-frame))
@@ -1811,20 +1847,26 @@ Non-nil for optional argument PRESERVE keeps all current buffers."
   "Return the window number if selected-frame is a member of window list."
   (let ((i 1) (sf (selected-frame)) found)
     (while (and (< i win:max-configs) (not found))
-      (if (eq sf (aref win:configs i))
+      (if (eq sf (win:get-frame i))
 	  (setq found t))
       (setq i (1+ i)))
     (if found (1- i))))
 
+(defconst win:frames-in-nw
+  (and (null window-system)
+       (fboundp 'window-configuration-frame) ;not in XEmacs
+       (fboundp 'make-frame)
+       (string< "20" emacs-version))
+  "Flags whether using frame feature in -nw mode or not.")
 (defun win:adjust-window (&optional noerror)
   "Adjust win:current-config to (selected-frame).
 If optional argument NOERROR is non-nil, do not stop even if the selected
 window is not a member of window list."
   (interactive)
   (cond
-   (win:use-frame
+   ((or win:use-frame win:frames-in-nw)
     (catch 'escape
-      (if (eq (aref win:configs win:current-config) (selected-frame))
+      (if (eq (win:get-frame win:current-config) (selected-frame))
 	  nil				;selected frame is current window.
 	(let ((sw (win:selected-window)))
 	  (if (not sw)
@@ -1835,7 +1877,8 @@ window is not a member of window list."
 		  win:current-config sw)
 	    (win:update-mode-line win:current-config))))
       (if (and win:title-with-buffer-name (not win:xemacs-p)
-	       win:frame-title-function)
+	       win:frame-title-function
+	       (not win:frames-in-nw))
 	  (modify-frame-parameters
 	   nil
 	   (list
@@ -1875,7 +1918,7 @@ window is not a member of window list."
 (defun win:memorize-current-conf-1 ()
   "(windows.el internal) Memorize recent window-configuration."
   (win:adjust-window t)
-  (aset win:memorized-winconf win:current-config (current-window-configuration)))
+  (aset win:memorized-winconf win:current-config (win:current-window-configuration)))
 
 (defun win:memorize-current-conf (&optional from to old)
   "Memorize recent window-configuration.
@@ -1904,8 +1947,8 @@ selected window.  Without ARG, selected window and its point reserved."
     (if (null memorized)
 	(message "No conf. yet.  Modify this buffer, and you get conf.")
       (aset win:memorized-winconf win:current-config
-	    (current-window-configuration))
-      (set-window-configuration memorized)
+	    (win:current-window-configuration))
+      (win:set-window-configuration memorized)
       (if (equal 1 arg)
 	  (progn
 	    (select-window sw)
@@ -2089,13 +2132,13 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
 	(setq goal (- (string-to-char goal) win:base-key))
 	(if win:use-frame (win:adjust-window))
 	(if (eq win:current-config (aref win:switch-menu-saved-config 0))
-	    (set-window-configuration (aref win:switch-menu-saved-config 1)))
+	    (win:set-window-configuration (aref win:switch-menu-saved-config 1)))
 	(or kill (win-switch-to-window 1 goal)))))
 
 (defun win-switch-menu-select-directly ()
   "Select the window directly from the keyboard in window selection menu."
   (interactive)
-  (let ((num (- last-command-char win:base-key)))
+  (let ((num (- (win:last-key) win:base-key)))
     (and
      (eq (get-buffer win:switch-menu-buffer) (current-buffer))
      (< num win:max-configs)
@@ -2104,7 +2147,7 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
      (progn
        (if win:use-frame (win:adjust-window))
        (if (eq win:current-config (aref win:switch-menu-saved-config 0))
-	   (set-window-configuration (aref win:switch-menu-saved-config 1)))
+	   (win:set-window-configuration (aref win:switch-menu-saved-config 1)))
        (win-switch-to-window 1 num)))))
 
 (defun win-switch-menu-mark-job (unmark)
@@ -2115,7 +2158,7 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
    (progn (beginning-of-line) (looking-at "[ A-Z]+(.)"))
    (let (buffer-read-only)		;bound to nil
      (delete-char 1)
-     (insert (if unmark " " (char-to-string (upcase last-command-char))))
+     (insert (if unmark " " (char-to-string (upcase (win:last-key)))))
      (forward-line 1)
      (and (eobp) (forward-line -1)))))
 
@@ -2148,7 +2191,7 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
 	    (win:load-window num)
 	    (if (= num current)		;override previous configuration.
 		(aset win:switch-menu-saved-config 1
-		      (current-window-configuration)))))
+		      (win:current-window-configuration)))))
 	 ((= job ?K)
 	  (if (aref win:configs num)
 	      (let ((win:last-config win:last-config))
@@ -2204,7 +2247,7 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
     (win:adjust-names)
     (or win:use-frame (win:store-config win:current-config)) ;save current state
     (aset win:switch-menu-saved-config 0 win:current-config)
-    (aset win:switch-menu-saved-config 1 (current-window-configuration))
+    (aset win:switch-menu-saved-config 1 (win:current-window-configuration))
     (if (< (window-height) (1+ win:max-configs))
         (enlarge-window (- win:max-configs (window-height)))))
   (win:switch-menu-prepare-menu)
@@ -2237,6 +2280,17 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
       (wrap-function-to-control-ime 'win-resume-menu t "P")
       (wrap-function-to-control-ime 'win-switch-menu t nil)))
 
+;;;
+;; Work-arounds
+;;;
+;for mew-5.2 or later (Suggested by masutaka)
+(if (fboundp 'defadvice)
+    (defadvice mew-buffer-message
+      (after mew-buffer-message-after-advice (&rest args) activate)
+      (or win:use-frame
+	  (setq ad-return-value
+		(format "%s%d" ad-return-value win:current-config)))))
+
 ;;;
 ;; Final setup.
 ;;;
@@ -2244,9 +2298,34 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
 (run-hooks 'win-load-hook)
 
 ;; $Log: windows.el,v $
-;; Revision 2.41  2007/06/06 11:29:29  yuuji
-;; Fix hook setup for KeyFunc&Exit.
-;; Suggested by Debian Project.
+;; Revision 2.48  2010/05/23 12:33:40  yuuji
+;; Workaround for frame focus on CarbonEmacs.
+;; Thanks to nabechan.
+;;
+;; Revision 2.47  2009/10/17 01:49:05  yuuji
+;; Fix for XEmacs and emacs-20.
+;;
+;; Revision 2.46  2009/09/02 05:09:33  yuuji
+;; ?\M-0 is no longer negative.
+;; Thanks to patch from rubikitch>at<ruby-lang.org.
+;;
+;; Revision 2.45  2009/09/02 04:48:06  yuuji
+;; Frame use in -nw mode fixed.
+;; In -nw mode, we should adjust window number after switching windows.
+;; Thanks to the comment from Francis Moreau.
+;;
+;; Revision 2.44  2008/06/08 21:55:54  yuuji
+;; In non-frame mode, displaying different point of the same buffer
+;; in two or more window can't be restored by set-window-configuration.
+;; For this work-around, define win:current-window-configuration and
+;; win:set-window-configuration. (thanks to sakurai>at<math.s.chiba-u.ac.jp)
+;;
+;; Revision 2.43  2008/05/14 13:08:51  yuuji
+;; We cannot use 'unless here.  Replaced it with or.
+;;
+;; Revision 2.42  2008/05/13 01:21:09  yuuji
+;; Work-around for Mew5 or later.
+;; Utilize make-frame in `emacs -nw'.
 ;;
 ;; Revision 2.41  2007/06/06 11:28:05  yuuji
 ;; Fix hook setup for KeyFunc&Exit.
